@@ -102,16 +102,8 @@ impl Kubectl {
         &self,
         crd: apiextensionsv1::CustomResourceDefinition,
     ) -> anyhow::Result<()> {
-        use anyhow::Context;
-        use kube::runtime::wait;
-        use wait::conditions::is_crd_established;
-
-        let crd = self.ensure_global_k_is_installed(crd).await?;
-        let name = crd.metadata.name.context("crd does not have name")?;
-
-        wait::await_condition(self.crds(), &name, is_crd_established())
-            .await
-            .context("failed to established crd")
+        self.create_global_crd(crd).await?;
+        Ok(())
     }
 
     pub async fn ensure_global_k_is_installed<K>(&self, object: K) -> kube::Result<K>
