@@ -392,14 +392,18 @@ impl super::Kubectl {
     where
         K: Ord + ser::Serialize + de::DeserializeOwned + Clone,
         V: ser::Serialize + de::DeserializeOwned + Clone,
-        F: Fn() -> anyhow::Result<V>,
+        F: Fn(&BTreeMap<K, V>) -> anyhow::Result<V>,
     {
-        use std::collections::btree_map::Entry::{Occupied, Vacant};
         let mut value = None;
         self.update_json_map(name, |cm_data: &mut BTreeMap<K, V>| {
-            let v = match cm_data.entry(key.clone()) {
-                Occupied(v) => Ok(v.get().clone()),
-                Vacant(e) => or_insert_with().map(|v| e.insert(v).clone()),
+            let v = if let Some(v) = cm_data.get(&key).cloned() {
+                Ok(v)
+            } else {
+                let res = or_insert_with(cm_data);
+                if let Ok(v) = &res {
+                    cm_data.insert(key.clone(), v.clone());
+                }
+                res
             };
             value = Some(v);
         })
